@@ -160,7 +160,7 @@ if __name__ == '__main__':
 
     filename = os.getcwd() + "\\cache\\" + "Lasku" + vals1.get('invoiceid')
 
-    with open("../res/template.tex", "r", encoding="utf-8") as template:
+    with open(sys.prefix+"\\res\\template.tex", "r", encoding="utf-8") as template:
         text = template.read()
 
         for key, value in vals1.items():
